# Draw motif logo
Python3 scripts to plot motif logo in HOCOMOCO style from PCM/PFM matrices


## Installation

```
pip3 install drawlogo
```

## Requirements
```
python >= 3.6
```

## Usage
```
drawlogo <options>...
```
or to import within python
```
from drawlogo.cli import draw_logo
```
To get full usage description one can execute:
```
drawlogo --help
```
The drawlogo package is maintained by Sergey Abramov and Alexandr Boytsov.